AppExit

Enum AppExit 

pub enum AppExit {
    Success,
    Error(NonZero<u8>),
}
A [Message] that indicates the [App] should exit. If one or more of these are present at the end of an update, the runner will end and (maybe) return control to the caller.

This message can be used to detect when an exit is requested. Make sure that systems listening for this message run before the current update ends.

Portability

This type is roughly meant to map to a standard definition of a process exit code (0 means success, not 0 means error). Due to portability concerns (see ExitCode and process::exit) we only allow error codes between 1 and 255.

Variants



Success

[App] exited without any problems.



Error(NonZero<u8>)

The [App] experienced an unhandleable error. Holds the exit code we expect our app to return.

Implementations



impl AppExit

pub const fn error() -> AppExit

Creates a AppExit::Error with an error code of 1.

pub const fn is_success(&self) -> bool

Returns true if self is a AppExit::Success.

pub const fn is_error(&self) -> bool

Returns true if self is a AppExit::Error.

pub const fn from_code(code: u8) -> AppExit

Creates a AppExit from a code.

When code is 0 a AppExit::Success is constructed otherwise a AppExit::Error is constructed.